#
# spec file for package python-django-picklefield
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define upstream_version 3.1
Name:           python-django-picklefield
Version:        3.1.0
Release:        3.1
Summary:        Pickled object field for Django
License:        MIT
URL:            https://github.com/gintas/django-picklefield
Source:         https://github.com/gintas/django-picklefield/archive/v%{version}.tar.gz
BuildRequires:  %{python_module Django >= 1.11}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 1.11
BuildArch:      noarch
%python_subpackages

%description
django-picklefield provides an implementation of a pickled object field.
Such fields can contain any picklable objects.

The implementation is taken and adopted from Django snippet #1694
<http://www.djangosnippets.org/snippets/1694/> by Taavi Taijala, which is in
turn based on Django snippet #513 <http://www.djangosnippets.org/snippets/513/>
by Oliver Beattie.

%prep
%setup -q -n django-picklefield-%{version}
echo 'DEFAULT_AUTO_FIELD="django.db.models.AutoField"' >> tests/settings.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m django test -v2 --settings=tests.settings

%files %{python_files}
%doc README.rst
%{python_sitelib}/picklefield
%{python_sitelib}/django_picklefield-%{upstream_version}.dist-info

%changelog
* Wed Apr  3 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Sprinkle in fdupes.
- No more greedy globs in %%files.
* Mon Jun 26 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 3.1.0:
  * Added testing against Django 3.2 and 4.0.
  * addressed a packaging issue with 3.0.0
* Tue May 10 2022 pgajdos@suse.com
- python-mock is not required for build
* Fri Jan  7 2022 John Vandenberg <jayvdb@gmail.com>
- Skip Tumbleweed Python 3.6 incompatible with Django 4
* Sat Jul 24 2021 John Vandenberg <jayvdb@gmail.com>
- Add missing DEFAULT_AUTO_FIELD to test settings.py for Django 3.2
* Wed Jun 10 2020 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 3.0.1
  * no changelog
* Tue Jun  9 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 3.0.0
  * Allowed default pickle protocol to be overriden using
    the PICKLEFIELD_DEFAULT_PROTOCOL setting.
  * Dropped support for Python 2.
  * Added testing against Django 3.0.
  * Dropped support for Django 1.11.
* Thu Feb 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.1:
  * no changelog
* Tue Dec 11 2018 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.0.0:
  * no changelog
- Enable tests
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 1.0.0
  * No changelog
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon May  4 2015 benoit.monin@gmx.fr
- update to version 0.3.1:
  * Favor the built in json module (thanks to Simon Charette).
- point the source URL to pypi
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Apr 14 2013 toddrme2178@gmail.com
- Remove pre_checkin.sh since the two versions are not the same
- Remove unneeded macros
- Added python buildrequires and requires since the package does not
  work properly without them on openSUSE <= 12.2
* Fri Apr 12 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Dec 10 2012 alexandre@exatati.com.br
- Update to 0.3.0:
  * Python 3 support (thanks to Rafal Stozek).
* Mon Apr 23 2012 alexandre@exatati.com.br
- Update to 0.2.1:
  * Use __slots__ to optimize _ObjectWrapper (thanks to Simon
    Charette).
* Wed Mar 14 2012 saschpe@suse.de
- Use upstream tarball
- Simplified macro usage
* Tue Feb 21 2012 alexandre@exatati.com.br
- Update to 0.2.0:
  * Allow pickling of subclasses of django.db.models.Model (thanks to
  Simon Charette)
- Regenerate spec file with py2pack.
* Tue Nov 16 2010 alexandre@exatati.com.br
- Update to 0.1.9.
* Mon Nov  8 2010 alexandre@exatati.com.br
- Update to 0.1.8;
- Bzip2 source file.
* Tue Apr 13 2010 alexandre@exatati.com.br
- Update to 0.1.6.
* Mon Apr  5 2010 alexandre@exatati.com.br
- Update to 0.1.5.
* Tue Mar 30 2010 alexandre@exatati.com.br
- Update to 0.1.4;
- Spec file cleaned with spec-cleaner.
* Sun Mar 28 2010 alexandre@exatati.com.br
- Update to 0.1.3.
* Sun Mar 28 2010 alexandre@exatati.com.br
- Update to 0.1.2.
* Fri Oct  9 2009 alexandre@exatati.com.br
- Initial package (0.1) for openSUSE.
